@@ -1198,6 +1198,12 @@ class TreeChord(XMLTree):
         except IndexError:
             pass
 
+        try:
+            stem = self.get_children_by_type(Stem)[0]
+            new_chord.add_child(stem)
+        except IndexError:
+            pass
+
         try:
             notehead = self.get_children_by_type(Notehead)[0]
             new_chord.add_child(notehead)
